@@ -6,8 +6,7 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef RESOURCE_H
-#define RESOURCE_H
+#pragma once
 
 #include "resourcetype.h"
 
@@ -309,7 +308,7 @@ public:
      */
     void close();
 
-    /** Return all events belonging to this resource. */
+    /** Return all events belonging to this resource, for enabled alarm types. */
     QList<KAEvent> events() const;
 
     /** Return the event with the given ID, provided its alarm type is enabled for
@@ -401,6 +400,5 @@ template <class T> T* Resource::resource() const
     return qobject_cast<T*>(mResource.data());
 }
 
-#endif // RESOURCE_H
 
 // vim: et sw=4:
